@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 __author__ = """Adrian Bulat"""
-__email__ = 'adrian.bulat@nottingham.ac.uk'
-__version__ = '1.1.0'
+__email__ = 'adrian@adrianbulat.com'
+__version__ = '1.2.0'
 
 from .api import FaceAlignment, LandmarksType, NetworkSize
